==> kipi-plugins-trinity_3.5.13.2.orig.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/picasawebexport/picasawebwidget.cpp <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2007-16-07
 * Description : a kipi plugin to export images to Picasa web service
 *
 * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

// TQt includes.

#include <tqpushbutton.h>
#include <tqlabel.h>
#include <tqframe.h>
#include <tqheader.h>
#include <tqlistview.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
#include <tqgroupbox.h>
#include <tqspinbox.h>
#include <tqcheckbox.h>
#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqsplitter.h>
#include <tqwhatsthis.h>
#include <tqlineedit.h>

// KDE includes.

#include <klocale.h>
#include <khtml_part.h>
#include <khtmlview.h>

// Local includes.

#include "picasawebwidget.h"
#include "picasawebwidget.moc"

namespace KIPIPicasawebExportPlugin
{

PicasawebWidget::PicasawebWidget(TQWidget* parent, const char* name, WFlags fl)
               : UploadWidget(parent, name, fl)
{
    if ( !name )
        setName("PicasawebWidget");

    //resize( TQSize(600, 400).expandedTo(minimumSizeHint()) );
    //clearWState( WState_Polished );
}

PicasawebWidget::~PicasawebWidget()
{
}

void PicasawebWidget::slotSelectionChecked()
{
//    kdDebug()<<"Slot Selection Checked "<<endl;
//    m_addPhotoBtn->setEnabled(m_selectImagesButton->isChecked());
}

void PicasawebWidget::slotResizeChecked()
{
//    m_dimensionSpinBox->setEnabled(m_resizeCheckBox->isChecked());
}

} // namespace KIPIPicasawebExportPlugin

==> kipi-plugins-trinity_14.2.0~pre111.orig.tar.xz: kipi-plugins-trinity-14.2.0~pre111+0a125237/kipi-plugins/picasawebexport/picasawebwidget.cpp <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2007-16-07
 * Description : a kipi plugin to export images to Picasa web service
 *
 * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

// TQt includes.

#include <tqpushbutton.h>
#include <tqlabel.h>
#include <tqframe.h>
#include <tqheader.h>
#include <tqlistview.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
#include <tqgroupbox.h>
#include <tqspinbox.h>
#include <tqcheckbox.h>
#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqsplitter.h>
#include <tqwhatsthis.h>
#include <tqlineedit.h>

// KDE includes.

#include <tdelocale.h>
#include <tdehtml_part.h>
#include <tdehtmlview.h>

// Local includes.

#include "picasawebwidget.h"
#include "picasawebwidget.moc"

namespace KIPIPicasawebExportPlugin
{

PicasawebWidget::PicasawebWidget(TQWidget* parent, const char* name, WFlags fl)
               : UploadWidget(parent, name, fl)
{
    if ( !name )
        setName("PicasawebWidget");

    //resize( TQSize(600, 400).expandedTo(minimumSizeHint()) );
    //clearWState( WState_Polished );
}

PicasawebWidget::~PicasawebWidget()
{
}

void PicasawebWidget::slotSelectionChecked()
{
//    kdDebug()<<"Slot Selection Checked "<<endl;
//    m_addPhotoBtn->setEnabled(m_selectImagesButton->isChecked());
}

void PicasawebWidget::slotResizeChecked()
{
//    m_dimensionSpinBox->setEnabled(m_resizeCheckBox->isChecked());
}

} // namespace KIPIPicasawebExportPlugin
